@@ -8,12 +8,13 @@ from click_rich_help import StyledGroup
 
 from ._checks import pre_run_check
 from .pycashier import Pycashier
+from .term import theme
 from .utils import load_params
 
 
 def init_check(ctx, param, check):
     if not check:
-        pre_run_check()
+        pre_run_check(command=ctx.to_info_dict()["command"]["name"])
 
 
 def add_options(options):
@@ -267,7 +268,7 @@ options = {
     "combine": [
         Option(
             ["-i", "--input"],
-            help="source directory containing output files from [b cyan]pycashier extract[/]",
+            help="source directory containing output files from [hl]pycashier extract[/]",
             default="./outs",
             show_default=True,
             type=click.Path(exists=True, file_okay=False, path_type=Path),
@@ -326,13 +327,14 @@ CONTEXT_SETTINGS = dict(
 
 @click.group(
     cls=StyledGroup,
+    theme=theme,
     context_settings=CONTEXT_SETTINGS,
 )
 @click.version_option(package_name="pycashier", prog_name="pycashier")
 def cli():
     """Cash in on DNA Barcode Tags
     \n\n\n
-    See `[b cyan]pycashier COMMAND -h[/]` for more information.
+    See `[hl]pycashier COMMAND -h[/]` for more information.
     """
     pass
 
