@@ -1,6 +1,6 @@
 from .cluster import cluster
 from .read_filter import read_filter
-from .term import console
+from .term import term
 from .trim import trim
 
 
@@ -32,12 +32,9 @@ def extract_all(
 
         sample = fastq.name.split(".")[0]
 
-        print()
-        console.print(f"──────────────── {sample} ───────────────────", style="dim")
+        term.process(f"[hl]{sample}[/]", status="start")
 
-        with console.status(
-            f"Processing sample: [green]{sample}[/green]", spinner="dots12"
-        ):
+        with term.cash_in() as status:
 
             trim(
                 sample,
@@ -55,9 +52,12 @@ def extract_all(
                 unlinked_adapters,
                 skip_trimming,
                 verbose,
+                status,
             )
 
-            cluster(sample, pipeline, ratio, distance, quality, threads, verbose)
+            cluster(
+                sample, pipeline, ratio, distance, quality, threads, verbose, status
+            )
 
             read_filter(
                 sample,
@@ -71,6 +71,6 @@ def extract_all(
                 distance,
             )
 
-        console.print(f"[green]{sample}[/green]: processing completed")
+        term.process(status="end")
 
-    console.print("\n[green]FINISHED!")
+    term.print("\n[green]FINISHED!")
