@@ -1,7 +1,7 @@
 from .extract import extract_all
 from .merge import merge_all
 from .single_cell import single_cell
-from .term import console
+from .term import term
 from .termui import print_params, sample_check
 from .utils import combine_outs, get_fastqs, save_params, validate_filter_args
 
@@ -39,16 +39,16 @@ class Pycashier:
         extract DNA barcodes from a directory of fastq files
 
         \b
-        Sample names should be delimited with a ".", such as `[b cyan][yellow]<sample>[/yellow].raw.fastq[/]`,
-        anything succeeding the first period will be ignored by `[b cyan]pycashier[/]`.
+        Sample names should be delimited with a ".", such as `[hl][yellow]<sample>[/yellow].raw.fastq[/]`,
+        anything succeeding the first period will be ignored by `[hl]pycashier[/]`.
 
-        If your data is paired-end with overlapping barcodes, see `[b cyan]pycashier merge[/]`.
+        If your data is paired-end with overlapping barcodes, see `[hl]pycashier merge[/]`.
         """
 
         # validate that filter count and filter percent aren't both defined
         filter = validate_filter_args(ctx)
 
-        console.print(("[b]\n[cyan]PYCASHIER:[/cyan] Starting Extraction\n"))
+        term.print(("[b]\n[cyan]PYCASHIER:[/cyan] Starting Extraction\n"))
 
         fastqs = get_fastqs(input)
 
@@ -91,11 +91,11 @@ class Pycashier:
         """
         merge overlapping paired-end reads using fastp
         \n\n\n
-        Simple wrapper over `[b cyan]fastp[/]` to combine R1 and R2 from PE fastq files.
+        Simple wrapper over `[hl]fastp[/]` to combine R1 and R2 from PE fastq files.
         \n\n\n
         """
 
-        console.print(("[b]\n[cyan]PYCASHIER:[/cyan] Starting Merge\n"))
+        term.print(("[b]\n[cyan]PYCASHIER:[/cyan] Starting Merge\n"))
 
         merge_all(
             [f for f in input.iterdir()],
@@ -127,15 +127,13 @@ class Pycashier:
         \n
         \b
         Designed for interoperability with 10X scRNA-seq workflow.
-        After processing samples with `[b cyan]cellranger[/]` resulting
-        bam files should be converted to sam files using `[b cyan]samtools[/]`.
+        After processing samples with `[hl]cellranger[/]` resulting
+        bam files should be converted to sam files using `[hl]samtools[/]`.
         \n
         [i]NOTE[/]: You can speed this up by providing a sam file with only
         the unmapped reads.
         """
-        console.print(
-            ("[b]\n[cyan]PYCASHIER:[/cyan] Starting Single Cell Extraction\n")
-        )
+        term.print(("[b]\n[cyan]PYCASHIER:[/cyan] Starting Single Cell Extraction\n"))
 
         single_cell(
             input,
@@ -157,7 +155,7 @@ class Pycashier:
         output,
     ):
         """
-        combine resulting output of [b cyan]extract[/]
+        combine resulting output of [hl]extract[/]
         """
 
         combine_outs(input, output)
