@@ -1,5 +1,3 @@
-import shlex
-import subprocess
 import sys
 import tempfile
 from pathlib import Path
@@ -9,10 +7,10 @@ try:
 except ImportError:
     pass
 
-from rich.progress import Progress
-from rich.prompt import Confirm
+from rich.progress import Progress, SpinnerColumn, TimeElapsedColumn
 
-from .term import console
+from .term import term
+from .utils import check_output, confirm_samples, run_cmd
 
 
 def sam_to_name_labeled_fastq(sample, in_file, out_file):
@@ -24,7 +22,7 @@ def sam_to_name_labeled_fastq(sample, in_file, out_file):
             new_sam = True
 
     if new_sam:
-        console.print(f"[green]{sample}[/green]: sam is headerless, adding a fake one")
+        term.process("sam is headerless, adding a fake one")
         sam_file = fake_header_add(in_file)
     else:
         sam_file = in_file
@@ -34,8 +32,15 @@ def sam_to_name_labeled_fastq(sample, in_file, out_file):
 
     with open(out_file, "w") as f_out:
 
-        with Progress() as progress:
-            task = progress.add_task("[red] Converting sam to fastq", total=sam_length)
+        with Progress(
+            SpinnerColumn("pipe", style="line"),
+            *Progress.get_default_columns(),
+            "Elapsed:",
+            TimeElapsedColumn(),
+            transient=True,
+            console=term._console,
+        ) as progress:
+            task = progress.add_task("[red]sam -> fastq", total=sam_length)
 
             for record in sam:
 
@@ -191,7 +196,7 @@ def fake_header_add(in_file):
 
 def single_cell_process(
     sample,
-    f,
+    samfile,
     pipeline,
     output,
     error,
@@ -205,56 +210,37 @@ def single_cell_process(
 ):
 
     adapter_string = f"-g {upstream_adapter} -a {downstream_adapter}"
-    input_file = f
-    fastq_out = pipeline / f"{sample}.cell_record_labeled.fastq"
-    output_file = pipeline / f"{sample}.cell_record_labeled.barcode.fastq"
+    fastq, barcode_fastq = (
+        pipeline / f"{sample}.cell_record_labeled.{ext}"
+        for ext in ("fastq", "barcode.fastq")
+    )
     tsv_out = output / f"{sample}.cell_record_labeled.barcode.tsv"
 
-    if not fastq_out.is_file():
-        console.print(f"[green]{sample}[/green]: converting sam to labeled fastq")
+    if check_output(fastq, "converting sam to labeled fastq"):
         status.stop()
-        sam_to_name_labeled_fastq(sample, input_file, fastq_out)
+        sam_to_name_labeled_fastq(sample, samfile, fastq)
         status.start()
     else:
-        console.print(
-            f"[green]{sample}[/green]: skipping sam to labeled fastq conversion"
+        term.process("skipping sam to labeled fastq conversion")
+
+    if check_output(barcode_fastq, "extracting barcodes w/ [b]cutadapt[/]"):
+
+        command = (
+            "cutadapt "
+            f"-e {error} "
+            f"-j {threads} "
+            f"--minimum-length={minimum_length} "
+            f"--maximum-length={length} "
+            "--max-n=0 "
+            f"--trimmed-only {adapter_string} "
+            "-n 2 "
+            f"-o {barcode_fastq} {fastq}"
         )
 
-    if not output_file.is_file():
+        run_cmd(command, sample, barcode_fastq, verbose, status)
 
-        console.print(f"[green]{sample}[/green]: extracting barcodes")
-
-        command = f"cutadapt \
-            -e {error} \
-            -j {threads} \
-            --minimum-length={minimum_length} \
-            --maximum-length={length} \
-            --max-n=0 \
-            --trimmed-only {adapter_string} \
-            -n 2 \
-            -o {output_file} {fastq_out}"
-
-        args = shlex.split(command)
-
-        p = subprocess.run(
-            args,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.STDOUT,
-            universal_newlines=True,
-        )
-
-        if verbose:
-            console.print("[yellow]CUTADAPT OUTPUT:")
-            console.print(p.stdout)
-
-    if not tsv_out.is_file():
-        console.print(f"[green]{sample}[/green]: converting labeled fastq to tsv")
-        labeled_fastq_to_tsv(output_file, tsv_out)
-
-    else:
-        console.print(
-            f"[green]{sample}[/green]: skipping labeled fastq to tsv conversion"
-        )
+    if check_output(tsv_out, "converting labeled fastq to tsv"):
+        labeled_fastq_to_tsv(barcode_fastq, tsv_out)
 
 
 def single_cell(
@@ -274,32 +260,30 @@ def single_cell(
         d.mkdir(exist_ok=True)
 
     # TODO: raise error if can't get sample name
-    sam_files = {f.name.split(".")[0]: f for f in input.iterdir()}
+    samfiles = {
+        f.name.split(".")[0]: f for f in input.iterdir() if not f.name.startswith(".")
+    }
 
-    for f in sam_files.values():
+    for f in samfiles.values():
 
-        ext = f.suffix
+        if f.suffix != ".sam":
+            print(
+                f"[ScrnaError]: There is a non sam file in the provided input directory: {f}",
+                err=True,
+            )
+            sys.exit(1)
 
-        if ext != ".sam":
-            raise ValueError("There is a non sam file in the provided input directory:")
+    confirm_samples(samfiles.keys(), yes)
 
-    console.print(f"[b cyan]Samples[/]: {', '.join(sorted(sam_files.keys()))}\n")
+    for sample, samfile in samfiles.items():
 
-    if not yes and not Confirm.ask("Continue with these samples?"):
-        sys.exit()
+        term.process(f"[hl]{sample}[/]", status="start")
 
-    for sample, f in sam_files.items():
+        with term.cash_in() as status:
 
-        print()
-        console.print(f"──────────────── {sample} ───────────────────", style="dim")
-
-        with console.status(
-            f"Processing sample: [green]{sample}[/green]\r\n",
-            spinner="dots12",
-        ) as status:
             single_cell_process(
                 sample,
-                f,
+                samfile,
                 pipeline,
                 output,
                 error,
@@ -311,7 +295,8 @@ def single_cell(
                 verbose,
                 status,
             )
-        console.print(f"[green]{sample}[/green]: processing completed")
 
-    console.print("\n[green]FINISHED!")
+        term.process(status="end")
+
+    term.print("\n[green]FINISHED!")
     sys.exit()
