@@ -1,25 +1,28 @@
 import csv
+import shlex
+import subprocess
 import sys
 from pathlib import Path
 
 import click
 import tomlkit
 
-from .term import console
+from .term import term
 
 
 def get_fastqs(src):
-    fastqs = [f for f in src.iterdir()]
+    fastqs = [f for f in src.iterdir() if not f.name.startswith(".")]
     if not fastqs:
-        console.print(f"Source dir: {src}, appears to be empty...")
-        console.print("Exiting.")
+        term.print(f"Source dir: {src}, appears to be empty...")
+        term.print("Exiting.")
         sys.exit(1)
 
     for f in fastqs:
 
         if not any(f.name.endswith(suffix) for suffix in [".fastq", ".fastq.gz"]):
             print(
-                f"ERROR! There is a non fastq file in the provided fastq directory: {f}"
+                f"[InputError]: There is a non fastq file in the provided fastq directory: {f}",
+                err=True,
             )
             print("Exiting.")
             sys.exit(1)
@@ -62,7 +65,7 @@ def combine_outs(input, output):
 
     files = {f.name.split(".")[0]: f for f in input.iterdir()}
 
-    console.print(f"Combing output files for {len(files)} samples.")
+    term.print(f"Combing output files for {len(files)} samples.")
 
     with output.open("w") as csv_out:
         csv_out.write("sample\tsequence\tcount\n")
@@ -111,11 +114,11 @@ def save_params(ctx):
         raise click.BadParameter("use `--save-config` with a specified `--config`")
 
     if config_file.is_file():
-        console.print(f"Updating current config file at [b cyan]{config_file}")
+        term.print(f"Updating current config file at [hl]{config_file}")
         with config_file.open("r") as f:
             config = tomlkit.load(f)
     else:
-        console.print(f"Staring a config file at [b cyan]{config_file}")
+        term.print(f"Staring a config file at [hl]{config_file}")
         config = tomlkit.document()
 
     if save_type == "explicit":
@@ -139,7 +142,7 @@ def save_params(ctx):
     with config_file.open("w") as f:
         f.write(tomlkit.dumps(config))
 
-    console.print("Exiting...")
+    term.print("Exiting...")
     ctx.exit()
 
 
@@ -153,5 +156,75 @@ def load_params(ctx, param, filename):
             params = tomlkit.load(f)
         if params:
             ctx.default_map = params.get(ctx.info_name, {})
+    elif Path(filename) != Path("pycashier.toml"):
+        term.print(
+            f"[InputError]: Specified config file ({filename}) does not exist.",
+            err=True,
+        )
+        sys.exit(1)
 
     ctx.obj = {"config_file": filename}
+
+
+def exit_status(p, file):
+    return True if p.returncode != 0 or file.stat().st_size == 0 else False
+
+
+def run_cmd(command, sample, output, verbose, status):
+    """run a subcommand"""
+    cmd_name = command.split()[0]
+
+    p = subprocess.run(
+        shlex.split(command),
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+        universal_newlines=True,
+    )
+    # remove 'progress: ##%' output from starcode
+    stdout = (
+        p.stdout
+        if not cmd_name == "starcode"
+        else "\n".join(
+            [line for line in p.stdout.splitlines() if not line.startswith("progress")]
+        )
+    )
+
+    if verbose or exit_status(p, output):
+        term.subcommand(sample, cmd_name, command, stdout)
+
+    if exit_status(p, output):
+        status.stop()
+        term.print(
+            f"[{cmd_name.capitalize()}Error]: Failed to extract reads for sample: [green]{sample}[/green]\n"
+            f"see above for {cmd_name} output",
+            err=True,
+        )
+        sys.exit(1)
+
+
+def confirm_samples(samples, yes):
+    """display and confirm samples"""
+
+    term.print(f"[hl]Samples[/]: {', '.join(sorted(samples))}\n")
+    if not yes and not term.confirm("Continue with these samples?"):
+        sys.exit()
+    if not yes:
+        term.print()
+
+
+def check_output(file, message):
+    """check for output file and print message
+
+    Args:
+        file (path.Pathlib): resulting file of step
+        message (str): text to display related to step
+    Returns:
+        bool
+    """
+
+    if not file.is_file():
+        term.process(message)
+        return True
+    else:
+        term.process(message, status="skip")
+        return False
